@@ -198,7 +198,7 @@ def root():
 
     # option = input(' Digite uma opção:\n [1] para traduzir arquivos modificados desde o último commit,\n [2] para traduzir todo o projeto, ou\n [Enter] para sair: ')
 
-    @root.command()
+    @root.command('diff')
     @click.pass_context
     def diff(workTree):
         if workTree:
@@ -235,7 +235,7 @@ def root():
         if cont != 'c': PrRed('\n\n Exiting...')
         time.sleep(1)
 
-    @root.command()
+    @root.command('all')
     def all():
         global processed
         global greenFlag
